==> igniteui-react-inputs-18.1.3.tgz: package/esm5/lib/XInputBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { typeCast, runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XInput } from "./XInput";
import { NativeUIInputChangingEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIInputDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { NativeUIInputType_$type } from "igniteui-react-core";
/**
 * @hidden
 */
var XInputBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XInputBridge, _super);
    function XInputBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.e = null;
        _this.d = null;
        _this.g = null;
        _this.f = null;
        return _this;
    }
    XInputBridge.prototype.addHandler = function (a, b, c, d) {
        var e = a;
        var f = typeCast(XInput.$, e.inputs._inner[0]);
        switch (c) {
            case 0:
                f.changing = delegateCombine(f.changing, runOn(this, this.i));
                this.e = d;
                this.g = b;
                break;
            case 2:
                f.change = delegateCombine(f.change, runOn(this, this.h));
                this.d = d;
                this.f = b;
                break;
        }
    };
    XInputBridge.prototype.removeHandler = function (a, b, c, d) {
        var e = a;
        var f = typeCast(XInput.$, e.inputs._inner[0]);
        switch (c) {
            case 0:
                f.changing = delegateRemove(f.changing, runOn(this, this.i));
                this.e = null;
                this.g = null;
                break;
            case 2:
                f.change = delegateRemove(f.change, runOn(this, this.h));
                this.d = null;
                this.f = null;
                break;
        }
    };
    XInputBridge.prototype.i = function (a, b) {
        if (this.e != null) {
            var c = new NativeUIInputChangingEventArgs();
            this.e(this.g, c);
        }
    };
    XInputBridge.prototype.h = function (a, b) {
        if (this.d != null) {
            var c = new NativeUIInputChangingEventArgs();
            this.d(this.f, c);
        }
    };
    XInputBridge.prototype.getValue = function (a, b) {
        var c = a;
        var d = typeCast(XInput.$, c.inputs._inner[0]);
        switch (b) {
            case 2: return d.cm;
            case 1:
                switch (c.n) {
                    case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                    case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                    case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                    case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                }
                break;
            case 0:
                switch (c.d) {
                    case 2: return enumGetBox(NativeUIInputDisplayType_$type, 1);
                    case 1: return enumGetBox(NativeUIInputDisplayType_$type, 2);
                    case 0: return enumGetBox(NativeUIInputDisplayType_$type, 0);
                }
                break;
            case 16: return enumGetBox(BaseControlTheme_$type, c.j);
            case 17:
                switch (d.b6) {
                    case "text": return enumGetBox(NativeUIInputType_$type, 0);
                    case "number": return enumGetBox(NativeUIInputType_$type, 1);
                }
                break;
        }
        return null;
    };
    XInputBridge.prototype.setValue = function (a, b, c) {
        var d = a;
        var e = typeCast(XInput.$, d.inputs._inner[0]);
        switch (b) {
            case 2:
                e.cm = c == null ? null : c.toString();
                break;
            case 1:
                switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                    case 0:
                        d.n = 0;
                        break;
                    case 1:
                        d.n = 1;
                        break;
                    case 2:
                        d.n = 3;
                        break;
                    case 3:
                        d.n = 2;
                        break;
                }
                break;
            case 0:
                switch (EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, c)) {
                    case 1:
                        d.d = 2;
                        break;
                    case 2:
                        d.d = 1;
                        break;
                    case 0:
                        d.d = 0;
                        break;
                }
                break;
            case 16:
                d.j = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                break;
            case 17:
                switch (EnumUtil.getEnumValue(NativeUIInputType_$type, c)) {
                    case 0:
                        e.b6 = "text";
                        break;
                    case 1:
                        e.b6 = "number";
                        break;
                }
                break;
        }
    };
    XInputBridge.prototype.getTargetForProperty = function (a, b) {
        switch (a) {
            case 9:
            case 10: return b;
        }
        return _super.prototype.getTargetForProperty.call(this, a, b);
    };
    XInputBridge.$t = markType(XInputBridge, 'XInputBridge', XComponentBridge.$);
    return XInputBridge;
}(XComponentBridge));
export { XInputBridge };

==> igniteui-react-inputs-18.6.1.tgz: package/esm5/lib/XInputBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { INativeUIInputBridge_$type } from "igniteui-react-core";
import { typeCast, runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XInput } from "./XInput";
import { NativeUIInputChangingEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIInputDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { NativeUIInputType_$type } from "igniteui-react-core";
import { NativeUIComponentHorizontalAlignment_$type } from "igniteui-react-core";
/**
 * @hidden
 */
var XInputBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XInputBridge, _super);
    function XInputBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.v = null;
        _this.u = null;
        _this.x = null;
        _this.w = null;
        return _this;
    }
    XInputBridge.prototype.addHandler = function (a, b, c, d) {
        var e = a;
        var f = typeCast(XInput.$, e.inputs._inner[0]);
        switch (c) {
            case 0:
                f.changing = delegateCombine(f.changing, runOn(this, this.z));
                this.v = d;
                this.x = b;
                break;
            case 2:
                f.change = delegateCombine(f.change, runOn(this, this.y));
                this.u = d;
                this.w = b;
                break;
        }
    };
    XInputBridge.prototype.removeHandler = function (a, b, c, d) {
        var e = a;
        var f = typeCast(XInput.$, e.inputs._inner[0]);
        switch (c) {
            case 0:
                f.changing = delegateRemove(f.changing, runOn(this, this.z));
                this.v = null;
                this.x = null;
                break;
            case 2:
                f.change = delegateRemove(f.change, runOn(this, this.y));
                this.u = null;
                this.w = null;
                break;
        }
    };
    XInputBridge.prototype.z = function (a, b) {
        if (this.v != null) {
            var c = new NativeUIInputChangingEventArgs();
            this.v(this.x, c);
        }
    };
    XInputBridge.prototype.y = function (a, b) {
        if (this.u != null) {
            var c = new NativeUIInputChangingEventArgs();
            this.u(this.w, c);
        }
    };
    XInputBridge.prototype.getValue = function (a, b) {
        var c = a;
        var d = typeCast(XInput.$, c.inputs._inner[0]);
        switch (b) {
            case 2: return d.cq;
            case 1:
                switch (c.t) {
                    case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                    case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                    case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                    case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                }
                break;
            case 0:
                switch (c.d) {
                    case 2: return enumGetBox(NativeUIInputDisplayType_$type, 1);
                    case 1: return enumGetBox(NativeUIInputDisplayType_$type, 2);
                    case 0: return enumGetBox(NativeUIInputDisplayType_$type, 0);
                }
                break;
            case 18: return enumGetBox(BaseControlTheme_$type, c.p);
            case 19:
                switch (d.b8) {
                    case "text": return enumGetBox(NativeUIInputType_$type, 0);
                    case "number": return enumGetBox(NativeUIInputType_$type, 1);
                }
                break;
            case 20:
                switch (d.dy) {
                    case 0: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 0);
                    case 2: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 2);
                    case 1: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 1);
                    case 3: return enumGetBox(NativeUIComponentHorizontalAlignment_$type, 3);
                }
                break;
            case 21: return d.a1;
            case 32: return d.disabled;
            case 33: return d.d8;
        }
        return null;
    };
    XInputBridge.prototype.setValue = function (a, b, c) {
        var d = a;
        var e = typeCast(XInput.$, d.inputs._inner[0]);
        switch (b) {
            case 2:
                e.cq = c == null ? null : c.toString();
                break;
            case 1:
                switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                    case 0:
                        d.t = 0;
                        break;
                    case 1:
                        d.t = 1;
                        break;
                    case 2:
                        d.t = 3;
                        break;
                    case 3:
                        d.t = 2;
                        break;
                }
                break;
            case 0:
                switch (EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, c)) {
                    case 1:
                        d.d = 2;
                        break;
                    case 2:
                        d.d = 1;
                        break;
                    case 0:
                        d.d = 0;
                        break;
                }
                break;
            case 18:
                d.p = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                break;
            case 19:
                switch (EnumUtil.getEnumValue(NativeUIInputType_$type, c)) {
                    case 0:
                        e.b8 = "text";
                        break;
                    case 1:
                        e.b8 = "number";
                        break;
                }
                break;
            case 20:
                switch (EnumUtil.getEnumValue(NativeUIComponentHorizontalAlignment_$type, c)) {
                    case 0:
                        e.dy = 0;
                        break;
                    case 2:
                        e.dy = 2;
                        break;
                    case 1:
                        e.dy = 1;
                        break;
                    case 3:
                        e.dy = 3;
                        break;
                }
                break;
            case 21:
                e.a1 = c;
                break;
            case 32:
                e.disabled = c;
                break;
            case 33:
                e.d8 = c;
                break;
        }
    };
    XInputBridge.prototype.getTargetForProperty = function (a, b) {
        switch (a) {
            case 9:
            case 10: return b;
        }
        return _super.prototype.getTargetForProperty.call(this, a, b);
    };
    XInputBridge.prototype.focus = function (a) {
        var b = this.t;
        var c = b.inputs._inner[0];
        c.focus(true);
    };
    XInputBridge.prototype.select = function (a) {
        var b = a;
        var c = b.inputs._inner[0];
        window.setTimeout(function () { return c.dp(); }, 0);
    };
    XInputBridge.prototype.setSelectionRange = function (a, b, c) {
        var d = a;
        var e = d.inputs._inner[0];
        window.setTimeout(function () { return e.dr(b, c); }, 0);
    };
    XInputBridge.$t = markType(XInputBridge, 'XInputBridge', XComponentBridge.$, [INativeUIInputBridge_$type]);
    return XInputBridge;
}(XComponentBridge));
export { XInputBridge };
